@@ -3,12 +3,13 @@
 from __future__ import annotations
 
 import os
+import re
 import sys
 from contextlib import contextmanager
 from functools import partial, wraps
 from importlib.metadata import version as pkgversion
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Callable
 
 from duty import duty, tools
 
@@ -27,14 +28,14 @@ PTY = not WINDOWS and not CI
 MULTIRUN = os.environ.get("MULTIRUN", "0") == "1"
 
 
-def pyprefix(title: str) -> str:  # noqa: D103
+def _pyprefix(title: str) -> str:
     if MULTIRUN:
         prefix = f"(python{sys.version_info.major}.{sys.version_info.minor})"
         return f"{prefix:14}{title}"
     return title
 
 
-def not_from_insiders(func: Callable) -> Callable:  # noqa: D103
+def _not_from_insiders(func: Callable) -> Callable:
     @wraps(func)
     def wrapper(ctx: Context, *args: Any, **kwargs: Any) -> None:
         origin = ctx.run("git config --get remote.origin.url", silent=True)
@@ -50,7 +51,7 @@ def not_from_insiders(func: Callable) -> Callable:  # noqa: D103
 
 
 @contextmanager
-def material_insiders() -> Iterator[bool]:  # noqa: D103
+def _material_insiders() -> Iterator[bool]:
     if "+insiders" in pkgversion("mkdocs-material"):
         os.environ["MATERIAL_INSIDERS"] = "true"
         try:
@@ -61,6 +62,12 @@ def material_insiders() -> Iterator[bool]:  # noqa: D103
         yield False
 
 
+def _get_changelog_version() -> str:
+    changelog_version_re = re.compile(r"^## \[(\d+\.\d+\.\d+)\].*$")
+    with Path(__file__).parent.joinpath("CHANGELOG.md").open("r", encoding="utf8") as file:
+        return next(filter(bool, map(changelog_version_re.match, file))).group(1)  # type: ignore[union-attr]
+
+
 @duty
 def changelog(ctx: Context, bump: str = "") -> None:
     """Update the changelog in-place with latest commits.
@@ -101,6 +108,7 @@ def changelog(ctx: Context, bump: str = "") -> None:
         bump: Bump option passed to git-changelog.
     """
     ctx.run(tools.git_changelog(bump=bump or None), title="Updating changelog")
+    ctx.run(tools.yore.check(bump=bump or _get_changelog_version()), title="Checking legacy code")
 
 
 @duty(pre=["check-quality", "check-types", "check-docs", "check-api"])
@@ -184,7 +192,7 @@ def check_quality(ctx: Context) -> None:
     """
     ctx.run(
         tools.ruff.check(*PY_SRC_LIST, config="config/ruff.toml"),
-        title=pyprefix("Checking code quality"),
+        title=_pyprefix("Checking code quality"),
     )
 
 
@@ -207,10 +215,10 @@ def check_docs(ctx: Context) -> None:
     """
     Path("htmlcov").mkdir(parents=True, exist_ok=True)
     Path("htmlcov/index.html").touch(exist_ok=True)
-    with material_insiders():
+    with _material_insiders():
         ctx.run(
             tools.mkdocs.build(strict=True, verbose=True),
-            title=pyprefix("Building documentation"),
+            title=_pyprefix("Building documentation"),
         )
 
 
@@ -258,9 +266,10 @@ def check_types(ctx: Context) -> None:
         ✓ Checking types
         ```
     """
+    os.environ["FORCE_COLOR"] = "1"
     ctx.run(
         tools.mypy(*PY_SRC_LIST, config_file="config/mypy.ini"),
-        title=pyprefix("Type-checking"),
+        title=_pyprefix("Type-checking"),
     )
 
 
@@ -303,7 +312,7 @@ def docs(ctx: Context, *cli_args: str, host: str = "127.0.0.1", port: int = 8000
         host: The host to serve the docs from.
         port: The port to serve the docs on.
     """
-    with material_insiders():
+    with _material_insiders():
         ctx.run(
             tools.mkdocs.serve(dev_addr=f"{host}:{port}").add_args(*cli_args),
             title="Serving documentation",
@@ -325,7 +334,7 @@ def docs_deploy(ctx: Context, *, force: bool = False) -> None:
         force: Whether to force deployment, even from non-Insiders version.
     """
     os.environ["DEPLOY"] = "true"
-    with material_insiders() as insiders:
+    with _material_insiders() as insiders:
         if not insiders:
             ctx.run(lambda: False, title="Not deploying docs without Material for MkDocs Insiders!")
         origin = ctx.run("git config --get remote.origin.url", silent=True, allow_overrides=False)
@@ -392,7 +401,7 @@ def build(ctx: Context) -> None:
 
 
 @duty
-@not_from_insiders
+@_not_from_insiders
 def publish(ctx: Context) -> None:
     """Publish source and wheel distributions to PyPI.
 
@@ -414,7 +423,7 @@ def publish(ctx: Context) -> None:
 
 
 @duty(post=["build", "publish", "docs-deploy"])
-@not_from_insiders
+@_not_from_insiders
 def release(ctx: Context, version: str = "") -> None:
     """Release a new version of the project.
 
@@ -486,12 +495,12 @@ def test(ctx: Context, *cli_args: str, match: str = "") -> None:
             select=match,
             color="yes",
         ).add_args("-n", "auto", *cli_args),
-        title=pyprefix("Running tests"),
+        title=_pyprefix("Running tests"),
     )
 
 
-class Seeds(list):  # noqa: D101
-    def __init__(self, cli_value: str = "") -> None:  # noqa: D107
+class _Seeds(list):
+    def __init__(self, cli_value: str = "") -> None:
         if cli_value:
             self.extend(int(seed) for seed in cli_value.split(","))
 
@@ -503,14 +512,14 @@ def fuzz(
     size: int = 20,
     min_seed: int = 0,
     max_seed: int = 1_000_000,
-    seeds: Seeds = Seeds(),  # noqa: B008
+    seeds: _Seeds = _Seeds(),  # noqa: B008
 ) -> None:
     """Fuzz Griffe against generated Python code.
 
     Parameters:
         ctx: The context instance (passed automatically).
         size: The size of the case set (number of cases to test).
-        seeds: Seeds to test or exclude.
+        seeds: Seeds to test or exclude (comma-separated integers).
         min_seed: Minimum value for the seeds range.
         max_seed: Maximum value for the seeds range.
     """
