@@ -5,6 +5,7 @@ from __future__ import annotations
 import inspect
 import sys
 from functools import cached_property
+from types import GetSetDescriptorType
 from typing import TYPE_CHECKING, Any, ClassVar
 
 from _griffe.enumerations import ObjectKind
@@ -49,10 +50,10 @@ class ObjectNode:
         try:
             obj = inspect.unwrap(obj)
         except Exception as error:  # noqa: BLE001
-            # inspect.unwrap at some point runs hasattr(obj, "__wrapped__"),
-            # which triggers the __getattr__ method of the object, which in
-            # turn can raise various exceptions. Probably not just __getattr__.
-            # See https://github.com/pawamoy/pytkdocs/issues/45
+            # `inspect.unwrap` at some point runs `hasattr(obj, "__wrapped__")`,
+            # which triggers the `__getattr__` method of the object, which in
+            # turn can raise various exceptions. Probably not just `__getattr__`.
+            # See https://github.com/pawamoy/pytkdocs/issues/45.
             logger.debug("Could not unwrap %s: %r", name, error)
 
         # Unwrap cached properties (`inspect.unwrap` doesn't do that).
@@ -130,6 +131,8 @@ class ObjectNode:
             return ObjectKind.METHOD_DESCRIPTOR
         if self.is_function:
             return ObjectKind.FUNCTION
+        if self.is_getset_descriptor:
+            return ObjectKind.GETSET_DESCRIPTOR
         if self.is_property:
             return ObjectKind.PROPERTY
         return ObjectKind.ATTRIBUTE
@@ -169,6 +172,11 @@ class ObjectNode:
         """Whether this node's object is a coroutine."""
         return inspect.iscoroutinefunction(self.obj)
 
+    @cached_property
+    def is_getset_descriptor(self) -> bool:
+        """Whether this node's object is a get/set descriptor."""
+        return isinstance(self.obj, GetSetDescriptorType)
+
     @cached_property
     def is_property(self) -> bool:
         """Whether this node's object is a property."""
@@ -221,6 +229,11 @@ class ObjectNode:
             return False
         return self.parent_is_class and isinstance(self_from_parent, classmethod)
 
+    @cached_property
+    def is_attribute(self) -> bool:
+        """Whether this node's object is an attribute."""
+        return self.kind is ObjectKind.ATTRIBUTE
+
     @cached_property
     def _ids(self) -> set[int]:
         if self.parent is None:
@@ -239,15 +252,20 @@ class ObjectNode:
     @cached_property
     def alias_target_path(self) -> str | None:
         """Alias target path of this node, if the node should be an alias."""
+        # Top-level objects can't have been imported.
         if self.parent is None:
             return None
 
-        # Get the path of the module the child was declared in.
+        # We can't ever know if an attribute was imported.
+        if self.is_attribute:
+            return None
+
+        # Get the path of the module the child object was declared in.
         child_module_path = self.module_path
         if not child_module_path:
             return None
 
-        # Get the module the parent object was declared in.
+        # Get the path of the module the parent object was declared in.
         parent_module_path = self.parent.module_path
         if not parent_module_path:
             return None
@@ -271,7 +289,11 @@ class ObjectNode:
         # as users most likely import from the public module and not the private one.
         if child_module_path.lstrip("_") in _builtin_module_names:
             child_module_path = child_module_path.lstrip("_")
+
+        # Child object is a module, return its path directly.
         if self.is_module:
             return child_module_path
+
+        # Rebuild the child object path.
         child_name = getattr(self.obj, "__qualname__", self.path[len(self.module.path) + 1 :])
         return f"{child_module_path}.{child_name}"
