@@ -43,7 +43,7 @@ def docstring_warning(
         except BuiltinModuleError:
             prefix = f"<module: {docstring.parent.module.name}>"  # type: ignore[union-attr]
         log = getattr(logger, log_level.value)
-        log(f"{prefix}:{(docstring.lineno or 0)+offset}: {message}")
+        log(f"{prefix}:{(docstring.lineno or 0) + offset}: {message}")
 
     warn(docstring, offset, message, log_level)
 
@@ -65,8 +65,8 @@ def parse_docstring_annotation(
         The string unchanged, or a new name or expression.
     """
     with suppress(
-        AttributeError,  # docstring has no parent that can be used to resolve names
-        SyntaxError,  # annotation contains syntax errors
+        AttributeError,  # Docstring has no parent that can be used to resolve names.
+        SyntaxError,  # Annotation contains syntax errors.
     ):
         code = compile(annotation, mode="eval", filename="", flags=PyCF_ONLY_AST, optimize=2)
         if code.body:  # type: ignore[attr-defined]
