@@ -247,8 +247,7 @@ class ModuleFinder:
         ]
 
         real_module_name = module_name
-        if real_module_name.endswith("-stubs"):
-            real_module_name = real_module_name[:-6]
+        real_module_name = real_module_name.removesuffix("-stubs")
         namespace_dirs = []
         for path in self.search_paths:
             path_contents = self._contents(path)
@@ -265,7 +264,7 @@ class ModuleFinder:
                             return Package(real_module_name, init_module, stubs if stubs.exists() else None)
                         init_module = abs_path / "__init__.pyi"
                         if init_module.exists():
-                            # Stubs package
+                            # Stubs package.
                             return Package(real_module_name, init_module, None)
                         namespace_dirs.append(abs_path)
 
@@ -324,7 +323,7 @@ class ModuleFinder:
             py_file = rel_subpath.suffix == ".py"
             stem = rel_subpath.stem
             if not py_file:
-                # .py[cod] and .so files look like `name.cpython-38-x86_64-linux-gnu.ext`
+                # `.py[cod]` and `.so` files look like `name.cpython-38-x86_64-linux-gnu.ext`.
                 stem = stem.split(".", 1)[0]
             if stem == "__init__":
                 # Optimization: since it's a relative path, if it has only one part
@@ -394,7 +393,7 @@ class ModuleFinder:
                         self.append_search_path(directory.path)
 
     def _filter_py_modules(self, path: Path) -> Iterator[Path]:
-        for root, dirs, files in os.walk(path, topdown=True):
+        for root, dirs, files in os.walk(path, topdown=True, followlinks=True):
             # Optimization: modify dirs in-place to exclude `__pycache__` directories.
             dirs[:] = [dir for dir in dirs if dir != "__pycache__"]
             for relfile in files:
@@ -462,7 +461,7 @@ def _handle_pth_file(path: Path) -> list[_SP]:
     for line in text.strip().replace(";", "\n").splitlines(keepends=False):
         line = line.strip()  # noqa: PLW2901
         if _re_import_line.match(line):
-            editable_module = path.parent / f"{line[len('import'):].lstrip()}.py"
+            editable_module = path.parent / f"{line[len('import') :].lstrip()}.py"
             with suppress(UnhandledEditableModuleError):
                 return _handle_editable_module(editable_module)
         if line and not line.startswith("#") and os.path.exists(line):  # noqa: PTH110
