@@ -1235,6 +1235,10 @@ class Alias(ObjectAliasMixin):
         """
         return self.final_target.lineno
 
+    @lineno.setter
+    def lineno(self, lineno: int | None) -> None:
+        self.final_target.lineno = lineno
+
     @property
     def endlineno(self) -> int | None:
         """The ending line number of the target object.
@@ -1243,6 +1247,10 @@ class Alias(ObjectAliasMixin):
         """
         return self.final_target.endlineno
 
+    @endlineno.setter
+    def endlineno(self, endlineno: int | None) -> None:
+        self.final_target.endlineno = endlineno
+
     @property
     def docstring(self) -> Docstring | None:
         """The target docstring.
@@ -1620,6 +1628,10 @@ class Alias(ObjectAliasMixin):
         """The attribute value."""
         return cast("Attribute", self.final_target).value
 
+    @value.setter
+    def value(self, value: str | Expr | None) -> None:
+        cast("Attribute", self.final_target).value = value
+
     @property
     def annotation(self) -> str | Expr | None:
         """The attribute type annotation."""
@@ -2075,9 +2087,25 @@ class Function(Object):
         Returns:
             The resolved name.
         """
-        # We're in an `__init__` method and name is a parameter name.
-        if self.parent and self.name == "__init__" and name in self.parameters:
-            return f"{self.parent.path}({name})"
+        # We're in an `__init__` method...
+        if self.parent and self.name == "__init__":
+            # ...and name is a parameter name: resolve to the parameter.
+            if name in self.parameters:
+                return f"{self.parent.path}({name})"
+
+            # Kind of a special case: we avoid resolving to instance-attributes from a function scope.
+            # See issue https://github.com/mkdocstrings/griffe/issues/367.
+            resolved = super().resolve(name)
+            try:
+                obj = self.modules_collection.get_member(resolved)
+            except KeyError:
+                return resolved
+            try:
+                if obj.is_attribute and "instance-attribute" in obj.labels:
+                    raise NameResolutionError(name)
+            except AliasResolutionError:
+                pass
+            return resolved
         return super().resolve(name)
 
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:
