@@ -2,15 +2,18 @@
 
 from __future__ import annotations
 
-from typing import Iterator
+from typing import TYPE_CHECKING
 
 import pytest
-from _griffe.docstrings import google, numpy, sphinx
 
+from _griffe.docstrings import google, numpy, sphinx
 from tests.test_docstrings.helpers import ParserType, parser
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
 
-@pytest.fixture()
+
+@pytest.fixture
 def parse_google() -> Iterator[ParserType]:
     """Yield a function to parse Google docstrings.
 
@@ -20,7 +23,7 @@ def parse_google() -> Iterator[ParserType]:
     yield from parser(google)
 
 
-@pytest.fixture()
+@pytest.fixture
 def parse_numpy() -> Iterator[ParserType]:
     """Yield a function to parse Numpy docstrings.
 
@@ -30,7 +33,7 @@ def parse_numpy() -> Iterator[ParserType]:
     yield from parser(numpy)
 
 
-@pytest.fixture()
+@pytest.fixture
 def parse_sphinx() -> Iterator[ParserType]:
     """Yield a function to parse Sphinx docstrings.
 
