@@ -2,7 +2,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Iterator, List, Protocol, Tuple, Union
+from typing import TYPE_CHECKING, Any, Protocol, Union
 
 from griffe import (
     Attribute,
@@ -15,11 +15,12 @@ from griffe import (
 )
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
     from types import ModuleType
 
 
 ParentType = Union[Module, Class, Function, Attribute, None]
-ParseResultType = Tuple[List[DocstringSection], List[str]]
+ParseResultType = tuple[list[DocstringSection], list[str]]
 
 
 class ParserType(Protocol):  # noqa: D101
@@ -40,10 +41,10 @@ def parser(parser_module: ModuleType) -> Iterator[ParserType]:
     Yields:
         The wrapped function.
     """
-    original_warn = parser_module._warn
+    original_warn = parser_module.docstring_warning
 
     def parse(docstring: str, parent: ParentType | None = None, **parser_opts: Any) -> ParseResultType:
-        """Parse a doctring.
+        """Parse a docstring.
 
         Parameters:
             docstring: The docstring to parse.
@@ -59,7 +60,9 @@ def parser(parser_module: ModuleType) -> Iterator[ParserType]:
             docstring_object.parent = parent
             parent.docstring = docstring_object
         warnings = []
-        parser_module._warn = lambda _docstring, _offset, message, log_level=LogLevel.warning: warnings.append(message)  # type: ignore[attr-defined]
+        parser_module.docstring_warning = (  # type: ignore[attr-defined]
+            lambda _docstring, _offset, message, log_level=LogLevel.warning: warnings.append(message)
+        )
         func_name = f"parse_{parser_module.__name__.split('.')[-1]}"
         func = getattr(parser_module, func_name)
         sections = func(docstring_object, **parser_opts)
@@ -67,4 +70,4 @@ def parser(parser_module: ModuleType) -> Iterator[ParserType]:
 
     yield parse
 
-    parser_module._warn = original_warn  # type: ignore[attr-defined]
+    parser_module.docstring_warning = original_warn  # type: ignore[attr-defined]
