@@ -103,7 +103,7 @@ def test_dont_overwrite_lower_member_when_expanding_wildcard() -> None:
 def test_load_data_from_stubs() -> None:
     """Check that the loader is able to load data from stubs / `*.pyi` files."""
     with temporary_pypackage("package", ["_rust_notify.pyi"]) as tmp_package:
-        # code taken from samuelcolvin/watchfiles project
+        # Code taken from samuelcolvin/watchfiles project.
         code = '''
             from typing import List, Literal, Optional, Protocol, Set, Tuple, Union
 
@@ -354,10 +354,10 @@ def test_load_builtin_modules() -> None:
     loader = GriffeLoader()
     loader.load("_ast")
     loader.load("_collections")
-    loader.load("_json")
+    loader.load("_operator")
     assert "_ast" in loader.modules_collection
     assert "_collections" in loader.modules_collection
-    assert "_json" in loader.modules_collection
+    assert "_operator" in loader.modules_collection
 
 
 def test_resolve_aliases_of_builtin_modules() -> None:
